(function( $ ) {
	'use strict';

	// Expand jQuery to encode the whitespaces correctly, we need it to send the form values correctly for payment methods
	$.fn.serializeAndEncode = function() {
		return $.map(this.serializeArray(), function(val) {
			return [val.name, encodeURIComponent(val.value)].join('=');
		}).join('&');
	};

    $(document).ready(function(){
        // Datepicker for selecting the log file of the desired day, set default date the current day
        $('.datepicker').datepicker({
            maxDate: "+0d",
            dateFormat: "dd/mm/yy"
        }).datepicker("setDate", new Date());

        if ($('.show-login-dialog').is(':visible')) {
            $('input[name=save]').toggle();
        }

    });

    // On download button click, check if the file exists in the server and if it is the case, download it, inform the user otherwise
    $(document).on('click', '#logDownloadButton', function(event) {

        event.preventDefault();
        event.stopPropagation();

        var log_date = $('.datepicker').val();

        $.ajax({
            url: 'admin-ajax.php',
            dataType: 'json',
            data: {
                action: 'check_for_log',
                _wpnonce: $('#_wpnonce').val(),
                date: log_date
            },
            error: function() {
                alert('Error trying to check for the logfile. Please contact Contasimple.');
            },
            success: function(response) {
                if (response == true) {
                    gtagCS('event', 'Download LOG file - Success', {
                        'event_category': 'Configuration',
                        'event_label': 'User clicked on download log and there were logged actions.'
                    });
                    var form_cs_download_log = $('#form-cs-download-log');
                    form_cs_download_log.append('<div><input type="text" name="log-date" value="' +  log_date  + '"/>');
                    form_cs_download_log.trigger('submit');
                } else {
                    gtagCS('event', 'Download LOG file - Empty', {
                        'event_category': 'Configuration',
                        'event_label': 'User clicked on download log, but there were logged actions.'
                    });
                    alert(js_translations.msg_log_not_found);
                }
            }
        });

    });
	
	$( document ).on('click', '#login-button', function(event) {

		event.preventDefault();
		event.stopPropagation();

		$.ajax({
			url: 'admin-ajax.php',
			dataType: 'json',
			data: {
				action: 'cs_login',
                _wpnonce: $('#_wpnonce').val(),
				apikey: $('#CONTASIMPLE_API_KEY').val()
			},
			beforeSend: function() {
                gtagCS('event', 'Connect via APIKEY', {
                    'event_category': 'Configuration',
                    'event_label': 'User clicked connect with key.' + $('#CONTASIMPLE_API_KEY').val()
                });
                disableButton('.btn-login');
                startLoadingButton('.btn-login');
			},
			success: function(response) {
                if (response.error) {
                    stopLoadingButton('.btn-login');
                    enableButton('.btn-login');
                    showErrorMessage('#login-status', response.message);
				} else {
                    $('#CONTASIMPLE_ACCOUNT_COMPANY').empty();
                    $.each(response.companies, function(i, company){
                        $('#CONTASIMPLE_ACCOUNT_COMPANY').append($('<option>', {
                            value: company.id_option,
                            text: company.name,
                            data: {
                                currency: company.currency,
                                country: company.country,
                                fiscalRegion: company.fiscalRegion
                            }
                        }));
                    });

                    if (response.companies) {
                        var contasimple_account_company_option = $('#CONTASIMPLE_ACCOUNT_COMPANY option');
                        $('#company-currency').text(contasimple_account_company_option.first().data('currency'));
                        $('#company-country').text(contasimple_account_company_option.first().data('country'));
                        $('#company-fiscal-region').text(contasimple_account_company_option.first().data('fiscalRegion'));

                        if (response.selectedCompany) {
                            var contasimple_account_company_option_selected = $('#CONTASIMPLE_ACCOUNT_COMPANY option[value=' + response.selectedCompany + ']');
                            contasimple_account_company_option_selected.attr("selected", "selected");
                            contasimple_account_company_option_selected.data('currency');
                            contasimple_account_company_option_selected.data('country');
                            contasimple_account_company_option_selected.data('fiscalRegion');
                        }

                        showSuccessMessage('#login-status', response.message, function () {
                            stopLoadingButton('.btn-login');
                        }, function () {
                            enableButton('.btn-login');
                            openSelectCompany();
                        });
                    } else {
                        stopLoadingButton('.btn-login');
                        enableButton('.btn-login');
                        showErrorMessage('#login-status', js_translations.msg_no_active_companies_found);
                    }
				}
			},
            error: function() {
                gtagCS('event', 'Connect via APIKEY - Error', {
                    'event_category': 'Configuration',
                    'event_label': 'User could not connect with APIKEY .' + $('#CONTASIMPLE_API_KEY').val()
                });
                stopLoadingButton('.btn-login');
                enableButton('.btn-login');
            }
		});
	});

	$( document ).on('click', '#select-company-button', function(event) {

		event.preventDefault();
		event.stopPropagation();

		$.ajax({
			url: 'admin-ajax.php',
			dataType: 'json',
			data: {
				action: 'cs_select_company',
                _wpnonce: $('#_wpnonce').val(),
				company: $('#CONTASIMPLE_ACCOUNT_COMPANY').val()
			},
			beforeSend: function() {
                disableButton('.btn-select-company');
                startLoadingButton('.btn-select-company');
			},
			success: function(response) {
                if (response.error) {
                    if (response.updateCompanyInfoStep) {
                        stopLoadingButton('.btn-select-company');
                        showErrorMessage('#company-status', response.message, function(){
                            enableButton('.btn-select-company');
                            openUpdateCompanyInfo();
                        })
                    } else {
                        stopLoadingButton('.btn-select-company');
                        enableButton('.btn-select-company');
                        showErrorMessage('#company-status', response.message);
                    }
                }
                else {
                    $('.cs-payment-method').empty();
                    $.each(response.paymentMethods, function(i, paymentMethod){
                        $('.cs-payment-method').append($('<option>', {
                            value: paymentMethod.id_option,
                            text: paymentMethod.name,
                            data: {
                            }
                        }));
                    });
                    showSuccessMessage('#company-status', response.message, function() {
                        stopLoadingButton('.btn-select-company');
                    }, function(){
                        enableButton('.btn-select-company');
                        openSelectPaymentMethod();
                    });
                }
			},
            error: function() {
                stopLoadingButton('.btn-select-company');
                enableButton('.btn-select-company');
            }
		});
	});

	$( document ).on('click', '#select-payment-method-button', function(event) {

		event.preventDefault();
		event.stopPropagation();	

        $.ajax({
            url: 'admin-ajax.php',
            dataType: 'json',
            data: {
                action: 'cs_select_payment_methods',
                _wpnonce: $('#_wpnonce').val(),
                data: $('#form-cs-payment-method').serializeAndEncode(),
            },
            beforeSend: function() {
                disableButton('.btn-select-payment-method');
                startLoadingButton('.btn-select-payment-method');
            },
            success: function(response) {
                if (response.error) {
                    stopLoadingButton('.btn-select-payment-method');
                    enableButton('.btn-select-payment-method');
                    showErrorMessage('#payment-method-status', response.message);
                } else {
                    showSuccessMessage('#payment-method-status', response.message, function() {
                        stopLoadingButton('.btn-select-payment-method');
                    }, function() {
                        window.location = window.location.href;
                    });
                }
            },
            error: function() {
                stopLoadingButton('.btn-select-payment-method');
                enableButton('.btn-select-payment-method');
            }
        });
    });	

	$(document).on('click', 'button[name="unlink"]', function() {
		$('#dialog-modal-unlink').modal('show').one('click', 'button[name="confirm-unlink"]', function(){
            gtagCS('event', 'Unlink account', {
                'event_category': 'Configuration',
                'event_label': 'User wants to unlink account.'
            });
			$('#form-cs-summary').trigger('submit');
		});
	});

	$(document).on('click', 'button[name="reset"]', function() {
		$('#dialog-modal-reset').modal('show').one('click', 'button[name="confirm-reset"]', function(){
            gtagCS('event', 'Unlink account and delete data', {
                'event_category': 'Configuration',
                'event_label': 'User wants to unlink account and reset data.'
            });
			$('#form-cs-summary').trigger('submit');
		});
	});
	
    $(document).on("hidden.bs.modal", "#dialog-modal-login", function () {
        stopLoadingButton('.btn-login');
        enableButton('.btn-login');
    });

    $(document).on('change', '#CONTASIMPLE_ACCOUNT_COMPANY', function() {
        var contasimple_account_company_option_selected = $('#CONTASIMPLE_ACCOUNT_COMPANY option:selected');
        $('#company-currency').text(contasimple_account_company_option_selected.data('currency'));
        $('#company-country').text(contasimple_account_company_option_selected.data('country'));
        $('#company-fiscal-region').text(contasimple_account_company_option_selected.data('fiscalRegion'));
    });

    function disableButton(buttonName) {
        $(buttonName).prop('disabled', true);
    }

    function startLoadingButton(buttonName) {
        $(buttonName).find("span").addClass("is-active");
    }

    function enableButton(buttonName) {
        $(buttonName).prop('disabled', false);
    }

    function stopLoadingButton(buttonName) {
        $(buttonName).find("span").removeClass("is-active");
    }

    function showErrorMessage(label, message, callback) {
        $(label).stop().addClass('text-danger').removeClass('text-success').fadeIn(200).text(message).delay(6000).fadeOut(200, callback);
    }

    function showSuccessMessage(label, message, callbackBefore, callbackAfter) {
        $(label).stop().addClass('text-success').removeClass('text-danger').fadeIn(200, callbackBefore).text(message).delay(2000).fadeOut(200, callbackAfter);
    }

    function openSelectCompany() {
        $('#dialog-modal-login').modal('hide');
        $('#dialog-modal-company').modal('show');
    }

    function openUpdateCompanyInfo() {
        $('#dialog-modal-company').modal('hide');
        $('#dialog-modal-update').modal('show');
    }

    function openSelectPaymentMethod() {
        $('#dialog-modal-company').modal('hide');
        $('#dialog-modal-update').modal('hide');
        $('#dialog-modal-payment-method').modal('show');
    }

})( jQuery );
