(function( $ ) {
	'use strict';

    $(document).ready(function(){
        $(document).tooltip({
            selector: '[rel="tooltip"]'
        })
    });

    var cancelBulkSync = false;

    $(document).on('click', '.cs_view', function () {
        $(this).attr('target', '_blank');
    });

    // Depending on the invoices state selected, we will enable/disable bulk action buttons.
    // A bulk action button can only be enabled if all the invoices are in the same state and thus the action applies to all of them
    $(document).on('click', '.check-column input[type=checkbox]', function() {
        setAvailableBulkActions();
    });

    $(document).on('click', '.button.action', function(event){
        var action = $(this).closest('.bulkactions').find('option:selected').attr('value'),
            summary = $('.notice-cs');


        if (action == 'cs_sync' || action == 'cs_stop' ) {
            event.preventDefault(); // Only prevent the post on our custom actions

            var checked = [];

            $('.check-column input:checked').each(function () {
                checked.push($(this).val());
            });

            // Stop action will be a one-POST, set-all step with a spinning icon running until the process is done (should be fast)
            if (action != "cs_sync") {
                // Spinning icon
                alert('TODO show spinner');

                $.ajax({
                    url: ajaxurl ,
                    type: 'POST',
                    data: {
                        action: action,
                        boxes: checked
                    },
                    dataType: 'json',
                    success: function(response) {
                        if (response.redirect) {
                            window.location.replace(response.redirect);
                        }

                        $.each(response.invoices, function(){
                            if (this.id) {
                                var row = $('input[value=' + [this.id] + ']').closest('tr'),
                                    btnContainer = row.find('.custom-action').parent();

                                var newButtons = btnContainer.clone();
                                newButtons.find('.custom-action').remove();
                                newButtons.append(response.buttons);

                                btnContainer.html(newButtons.html());

                                row.find('.message').replaceWith(this.message);
                                row.find('.state').replaceWith(this.icon);
                                //row.find('.date-sync').html(this.date_sync);
                            }
                        });

                        if (response.summary) {
                            summary.replaceWith(response.summary);
                        }
                    },
                    error: function (xhr, ajaxOptions, thrownError) {
                        summary.replaceWith(thrownError);
                        $("html, body").animate({ scrollTop: 0 }, "slow");
                    },
                    complete: function() {
                        alert('TODO remove spinner');
                        setAvailableBulkActions();
                    }
                });

                return;
            }

            // Otherwise, if it is a bulk sync request, this could be slow, we display a modal with a progress bar and a confirmation option to start the process
            var dialog_modal_bulk_sync = $('#dialog-modal-bulk-sync');
            dialog_modal_bulk_sync.attr('action', action);
            dialog_modal_bulk_sync.modal('show');

            // This is from the modal if "sync" action was chosen, on form submit do the stuff to send all invoices one after the other via AJAX and refresh the screen accordingly
            var formBulkSync = $('#form-cs-bulk-sync');
            formBulkSync.submit(function(event) {

                event.preventDefault();
                event.stopImmediatePropagation();
                gtagCS('event', 'Submit bulk sync', {
                    'event_category': 'Invoices Panel',
                    'event_label': 'User triggered a bulk sync process to send many invoices at once.'
                });

                // All invoices are first put to 'PENDING' state before bulk sync
                $.ajax({
                    url: $('#form-cs-bulk-sync').attr('action'),
                    type: 'POST',
                    data: {
                        action: 'cs_resume',
                        boxes: checked
                    },
                    dataType: 'json',
                    success: function(response) {
                        if (response.redirect) {
                            window.location.replace(response.redirect);
                            return;
                        }
                        $.each(response.invoices, function(){
                            if (this.id) {
                                var row = $('input[value=' + [this.id] + ']').closest('tr'),
                                    btnContainer = row.find('.custom-action').parent();

                                var newButtons = btnContainer.clone();
                                newButtons.find('.custom-action').remove();
                                newButtons.append(this.buttons);

                                btnContainer.html(newButtons.html());

                                row.find('.message').replaceWith(this.message);
                                row.find('.state').replaceWith(this.icon);
                            }
                        });

                        if (response.summary) {
                            summary.replaceWith(response.summary);
                        }
                    },
                    error: function (xhr, ajaxOptions, thrownError) {
                        summary.replaceWith(thrownError);
                        $("html, body").animate({ scrollTop: 0 }, "slow");
                    },
                    complete: function() {
                        setAvailableBulkActions();

                        // After the PENDING global state set, the process starts
                        // Cancel button will prevent the next sync but not the current one
                        cancelBulkSync = false;

                        var action = $('#dialog-modal-bulk-sync').attr('action'),
                            count = $('.check-column input:checked').length,
                            current = 0,
                            progress = 0;

                        if (count === 0) {
                            return;
                        }

                        // Getting PS translations into JS and updating DOM/CSS styles is a pain so it has been decided to have different sections rendered in HTML via TPL and show/hide accordingly
                        $('#bulk-sync-advise').hide();
                        $('#bulk-sync-processing').show();
                        $('.notice-cs').hide();

                        // The last pending invoice from the queue it's a different case and will trigger the transition to the main screen
                        var defLast = $.Deferred();

                        $.when(defLast).done(function () {
                            setTimeout(function(){
                                $('#cancel-bulk-sync-btn').attr('disabled', false);
                                $('#bulk-sync-processing').hide();
                                $('.notice-cs').show();

                                if (cancelBulkSync == true) {
                                    $('#dialog-modal-bulk-sync').modal('toggle');
                                } else {
                                    $('#bulk-sync-done').show();
                                }

                                setAvailableBulkActions();
                            }, 500); // A small pause so that the user can see the completion of the last invoice before clearing the screen
                        });

                        handleInvoicesSequentially();

                        function handleInvoicesSequentially() {

                            // We want to show a little bit of progress just for starting the queue
                            if (current === 0) {
                                progress = (100 / count) / 2;
                                $('.progress-bar').css('width', progress + '%').attr('aria-valuenow', progress);
                                var bulk_sync_processing = $('#bulk-sync-processing');
                                bulk_sync_processing.find('.icon-refresh').addClass('icon-spin');
                                $('#current').text(1);
                                $('#total').text(count);
                            }

                            var checked_column = $('.check-column input:checked');
                            // var invoice_order_id = $(checked_column[current]).val();
                            var def = $.Deferred();

                            // We call the sync action via the individual row button to not repeat ourselves
                            // In the end we want the process to be the same and update graphically each individual control behind the modal
                            $(checked_column[current]).closest('tr').find('.custom-action.' + action).trigger("click", def);

                            // Deferred object that will be resolved on ajax complete allows us to call the next one once the previous has finished
                            $.when(def).done(function () {
                                current++;
                                progress = current / count * 100;

                                $('#current').text(current);
                                $('.progress-bar').css('width', progress + '%').attr('aria-valuenow', progress);

                                if (current >= count || cancelBulkSync == true) {
                                    bulk_sync_processing.find('.icon-refresh').removeClass('icon-spin');
                                    defLast.resolve();
                                }

                                else {
                                    handleInvoicesSequentially();
                                }

                            }).fail(function () {
                                // TO DO
                            });
                        }
                    }
                });
            });

            // On modal hide reset config for the next attempt
            $(document).on("hidden.bs.modal", "#dialog-modal-bulk-sync", function () {
                $('#bulk-sync-advise').show();
                $('#bulk-sync-processing').hide();
                $('#bulk-sync-done').hide();
                $('.progress-bar').css('width', '0%').attr('aria-valuenow', 0);
            });

            $(document).on('click', '#cancel-bulk-sync-btn', function(){
                $(this).attr('disabled', true);
                cancelBulkSync = true;
                gtagCS('event', 'Cancel sync', {
                    'event_category': 'Invoices Panel',
                    'event_label': 'User canceled the sync process.'
                });
            });
        }
    });

    // Gather the needed info from the table row and send via AJAX to WP custom method
    $(document).on('click', '.custom-action.cs_sync, .custom-action.cs_stop, .custom-action.cs_resume ', function(event, deferred) {
        event.preventDefault();

        var btn = $(this),
            btnContainer = btn.parent(),
            url = btn.attr('href'),
            action = getURLParameter(url, 'action'),
            order_id = getURLParameter(url, 'order_id'),
            cs_invoice_id = getURLParameter(url, 'cs_invoice_id'),
            nonce = getURLParameter(url, '_wpnonce'),
            icon = btn.closest('tr').find('.view.cs_stop'),
            message = btn.closest('tr').find('.message'),
            sync_date = btn.closest('tr').find('.date-sync'),
            tablerow = btn.closest('tr'),
            summary = $('.notice-cs');

        gtagCS('event', 'Click invoice action', {
            'event_category': 'Invoices Panel',
            'event_label': 'User triggered a single, manual invoice action via one of the possible action buttons (depending on invoice state).',
            'event_action': action
        });

        // We keep a copy of elements since we could revert to previous message if request failed
        var buttonPrevious = btn.clone(),
            iconPrevious = icon.clone(),
            messagePrevious = message.clone();

        $.ajax({
            type: 'POST',
            url: ajaxurl, //btn.attr('href'),
            data: {
                action: action,
                nonce: nonce,
                order_id: order_id,
                cs_invoice_id: cs_invoice_id,
            },
            dataType: 'json',
            beforeSend: function() {
                btn.siblings().andSelf().each(function() {
                    $(this).addClass('disabled');
                });
                icon.removeClass('cs_stop').addClass('cs_processing');
                if (action == 'cs_stop') {
                    message.text(js_translations.msg_stopping).attr('style', '');
                }
                else {
                    message.text(js_translations.msg_syncing).attr('style', '');
                }
            },
            success: function(response) {
                if (response.redirect) {
                    window.location.replace(response.redirect);
                }

                else {
                    // Just remove all the whole row.
                    if ('cs_stop' === action) {
                        tablerow.remove();
                    }

                    // Update buttons to match the according new state possible custom actions.
                    if ('cs_sync' === action) {

                        var newButtons = btnContainer.clone();
                        newButtons.find('.custom-action').remove();
                        newButtons.append(response.buttons);

                        btnContainer.html(newButtons.html());
                        icon.replaceWith(response.icon);
                        message.replaceWith(response.message);

                        if (response.date_sync) {
                            sync_date.html(response.date_sync);
                        }

                        btn.siblings().andSelf().each(function() {
                            $(this).prop('disabled', false).css('pointer-events', 'auto');
                        });
                    }

                    if (response.summary) {
                        summary.replaceWith(response.summary);
                    }

                    // A deferred object is used to make AJAX calls one after the other
                    if (deferred !== undefined) {
                        deferred.resolve();
                    }
                }
            },
            error: function (xhr, ajaxOptions, thrownError){

                btn.replaceWith(buttonPrevious);
                icon.replaceWith(iconPrevious);
                message.replaceWith(messagePrevious);
                summary.replaceWith(thrownError);

                $("html, body").animate({ scrollTop: 0 }, "slow");

                if (deferred !== undefined) {
                    deferred.reject();
                }

            }
        });

        return false;
    });

    // Gather the needed info from the table row and send via AJAX to WP custom method
    $(document).on('click', '.custom-action.cs_email:not(.disabled), .custom-action.cs_email_sent:not(.disabled), .custom-action.cs_email_failed:not(.disabled)', function(event, deferred) {
        event.preventDefault();

        var btn = $(this),
            btnContainer = btn.parent().parent(), // btn.parent(); it seems an additional <p> wrapper was added...
            url = btn.attr('href'),
            action = getURLParameter(url, 'action'),
            cs_invoice_id = getURLParameter(url, 'cs_invoice_id'),
            nonce = getURLParameter(url, '_wpnonce'),
            icon = btn.closest('tr').find('.view.cs_email, .view.cs_email_sent, .view.cs_email_failed'),
            message = btn.closest('tr').find('.message'),
            sync_date = btn.closest('tr').find('.date-sync'),
            summary = $('.notice-cs');

        gtagCS('event', 'Click invoice action send email', {
            'event_category': 'Invoices Panel',
            'event_label': 'User triggered the send email button on invoices sync panel.'
        });

        // We keep a copy of elements since we could revert to previous message if request failed
        var buttonPrevious = btn.clone(),
            iconPrevious = icon.clone(),
            messagePrevious = message.clone();

        $.ajax({
            type: 'POST',
            url: ajaxurl, //btn.attr('href'),
            data: {
                action: action,
                _wpnonce: nonce,
                cs_invoice_id: cs_invoice_id
            },
            dataType: 'json',
            beforeSend: function() {
                btn.siblings().andSelf().each(function() {
                    $(this).prop('disabled', true).css('pointer-events', 'none');
                });
                //icon.attr('class', 'button tips custom-action view cs_processing');
                icon.removeClass('cs_email cs_email_failed cs_email_sent').addClass('cs_processing');
            },
            success: function(response) {
                if (response.redirect) {
                    window.location.replace(response.redirect);
                }

                btn.siblings().andSelf().each(function() {
                    $(this).prop('disabled', false).css('pointer-events', 'auto');
                });

                var newButtons = btnContainer.clone();
                newButtons.find('.custom-action').remove();
                newButtons.append(response.buttons);

                btnContainer.html(newButtons.html());

                if (response.summary) {
                    summary.replaceWith(response.summary);
                }
            },
            error: function (xhr, ajaxOptions, thrownError){

                summary.replaceWith(thrownError);

                $("html, body").animate({ scrollTop: 0 }, "slow");

                if (deferred !== undefined) {
                    deferred.reject();
                }

            }
        });

        return false;
    });

    function getURLParameter(url, name) {
        return (RegExp(name + '=' + '(.+?)(&|$)').exec(url)||[,null])[1];
    }

    function setAvailableBulkActions() {

        var actions = [],
            totalSelected = 0;

        // For each possible action we will maintain a counter of the times found, and if it's present in ALL of the selected invoices, then it can be enabled.
        $('.check-column input:checked').each(function () {
            $(this).closest('tr').find('.custom-action:not(.cs_view)').each(function (){
                var btn = $(this),
                    url = btn.attr('href'),
                    currentAction = getURLParameter(url, 'action');
                if (actions[currentAction] == null) {
                    actions[currentAction] = 1;
                }
                else {
                    actions[currentAction] += 1;
                }
            });
            totalSelected += 1;
        });

        // Easy way to handle clicked on/off. Hide all every time, and we will re-enable only the needed ones
        $(".bulkactions option[value^='cs_']").remove();

        // Now that we computed the number of options selected, enable/disable depending on if all of the selected invoices contain or not each action
        for (var key in actions) {
            if (actions[key] === totalSelected) {
                $('.bulkactions select').append($('<option>', {
                    value: key,
                    text: eval("js_translations.button_text_bulk_" + key)
                }));
            }
        }
    }

})( jQuery );
